package com.ruoyi.system.mapper;

import com.ruoyi.system.model.voucher.VoucherAuxiliary;
import com.ruoyi.system.model.voucher.VoucherBody;
import com.ruoyi.system.model.voucher.VoucherImportModel;
import org.springframework.data.repository.query.Param;

import java.util.List;

/**
 * @Author jiuli
 * @Date 2024/3/6
 */
public interface VoucherMapper {

    void saveHeadBatch(@Param("importModelList") List<VoucherImportModel> importModelList);

    void deleteHeadList(@Param("headIdList") List<String> headIdList);

    void deleteBodyList(@Param("headIdList") List<String> headIdList);

    void deleteAxiliarylist(@Param("bodyIdList") List<String> bodyIdList);

    void saveBodyBatch(@Param("voucherBodies") List<VoucherBody> voucherBodies);

    void saveAuxiliaryList(List<VoucherAuxiliary> voucherAuxiliaries);
}
